/*
   Accelerometer, ADXL345, test code
	
	8/20/2009
	Viliam Klein 
	
	This code sets up the power and mode registers and then prints out the data registers forever.
	UART is set to 9600 8N1
	
	using ATMega1284 on Breakout Board 5V, 16MHz board
	
	SCL -> SCK  (B7)
	SDA -> MOSI (B5)
	SDO -> MISO (B6)
	CS  -> SS	(B4)
	INT -> no connection, not used here

*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h> // needed for lcd_lib
#include "uart.c"

#define F_CPU 16000000UL

#define sbi(var, mask)   ((var) |= (uint8_t)(1 << mask))
#define cbi(var, mask)   ((var) &= (uint8_t)~(1 << mask))

//ADXL345
#define adxl PINB4 //PORTB


//Define functions
//======================
void ioinit(void);      //Initializes IO

FILE uart_str = FDEV_SETUP_STREAM(uart_putchar, uart_getchar, _FDEV_SETUP_RW);


void iniSPI(void);
void send_byte(uint8_t byte);
void send_dummy (void);
//void resetCS(uint16_t _delay);


//======================

int main (void)
{
    uint8_t recv1=0;
	uint8_t recv2=0;
	uint8_t byte;
	uint8_t data[6];
		
	ioinit();
	iniSPI();
	
	//printf("\nStart\n");
	
	_delay_ms(40000);//long _delay
	
	//waits for power register to respond correctly
	while(byte != 0x28)
	{
		//cbi(PORTB, adxl);
		send_byte(0x2D);
		send_byte(0x28);
		//sbi(PORTB, adxl);
		
		_delay_ms(5);
		
		//cbi(PORTB, adxl);
		send_byte(0xAD);
		send_byte(0x00);
		byte = SPDR;
		//sbi(PORTB, adxl);
		
		printf("Power is: %x\n", byte);
		
		_delay_ms(1000);
	}
	
	//cbi(PORTB, adxl);
	send_byte(0x31);
	send_byte(0x08);
	//sbi(PORTB, adxl);
	
	_delay_ms(5);
	
	//cbi(PORTB, adxl);
	send_byte(0xB1);
	send_byte(0x00);
	byte = SPDR;
	//sbi(PORTB, adxl);
	
	printf("Format is: %x\n", byte);
	
	//cbi(PORTB, adxl);
	send_byte(0x38);
	send_byte(0x00);
	//sbi(PORTB, adxl);
	
	_delay_ms(5);
	
	//cbi(PORTB, adxl);
	send_byte(0xB8);
	send_byte(0x00);
	byte = SPDR;
	//sbi(PORTB, adxl);
	
	printf("FIFO is: %x\n", byte);
		
	
	printf("data is: ");
	
	while(1)
	{
	printf("\n");
	
		//cbi(PORTB, adxl);
		send_byte(0xF2);
		
		for(uint8_t i=0; i<6; i++)
		{
			send_byte(0x00);
			data[i] = SPDR;
			
		}
		
		//sbi(PORTB, adxl);
		
		for(int i=0; i<6; i++)
		{
			printf("%x ",data[i]);
		}
		
		_delay_ms(100);
	
	}
	
	return(0);
}

 void send_dummy(void)
{

	SPDR = 0xAA;
	while(!(SPSR & (1<<SPIF)));

}

void send_byte(uint8_t byte)
{

	SPDR = byte;
	while(!(SPSR & (1<<SPIF)));

}

char ReadByteSPI(char addr)
{
	SPDR = addr;					//Load byte to Data register
	while(!(SPSR & (1<<SPIF))); 	// Wait for transmission complete 
	addr=SPDR;
	return addr;
}

void iniSPI(void)
{
	// Set MOSI, SCK, and SS output, all others input 
	DDRB |= (1<<PINB4)|(1<<PINB5) | (1<<PINB7);	 // Set MOSI , SCK , and SS output
	
	//sbi(PORTB, adxl);
	
	SPCR = ( (1<<SPE)|(1<<MSTR) | (1<<SPR1) |(1<<SPR0));	// Enable SPI, Master, set clock rate fck/128  

	//sbi(SPSR, 0);
    _delay_ms(1);
}


void ioinit (void)
{

	
    //1 = output, 0 = input
    DDRB = 0b00000000; //All inputs
	//PORTB = 0b00000000;
    DDRC = 0b00000011; //PORTC1 (SDA), PORTC0 (SCL)
    //DDRD = 0b000000000; //PORTD (RX on PD0)
	PORTC = 0b00000011; //pullups on the I2C bus
	//sbi(PORTD, 2);
	uart_init();
	stdout = stdin = stderr = &uart_str;
	fprintf(stdout,"Starting gyro...\n\r");

}

